Struct ZcosmicToplevelManagerV1

pub struct ZcosmicToplevelManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
control open apps

This protocol allows clients such as a taskbar to request the compositor to preform typical actions on open toplevels. The compositor is in all cases free to ignore the request.

See also the Event enum for this interface.

Implementations

Source

impl ZcosmicToplevelManagerV1

pub fn destroy(&self)

destroy the zcosmic_toplevel_manager_v1

This request indicates that the client has finished using the zcosmic_toplevel_manager_v1 object and that it can be safely destroyed.

pub fn close(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be closed

If the compositor honors this request, the zcosmic_toplevel_handle_v1.closed event will be sent.

pub fn activate(&self, toplevel: &ZcosmicToplevelHandleV1, seat: &WlSeat)

request that a toplevel be activated

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn set_maximized(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be maximized

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn unset_maximized(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be unmaximized

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn set_minimized(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be minimized

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn unset_minimized(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be unminimized

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn set_fullscreen( &self, toplevel: &ZcosmicToplevelHandleV1, output: Option<&WlOutput>, )

request that a toplevel be fullscreened

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state and potentially the zcosmic_toplevel_handle_v1.output_enter/output_leave events will be sent.

The output parameter a hint to the compositor and may be ignored. A value of NULL indicates that the compositor should choose the target output, if it honors the fullscreen request.

pub fn unset_fullscreen(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be unfullscreened

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn set_rectangle( &self, toplevel: &ZcosmicToplevelHandleV1, surface: &WlSurface, x: i32, y: i32, width: i32, height: i32, )

designate a rectangle to represent a toplevel

If a client using this protocol displays UI elements corresponding to toplevels, it may use this request to inform the server about such a relation. This information may be used by the server, for example as the target for a minimize animation.

If the client sets more than one rectangle, only the most recently set rectangle is considered.

The dimensions are given in surface-local coordinates.

Setting width=height=0 removes the current rectangle if one was set.

pub fn move_to_workspace( &self, toplevel: &ZcosmicToplevelHandleV1, workspace: &ZcosmicWorkspaceHandleV1, output: &WlOutput, )

move toplevel to workspace

Move window to workspace, on given output.

pub fn set_sticky(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be made sticky

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn unset_sticky(&self, toplevel: &ZcosmicToplevelHandleV1)

request that a toplevel be removed of the sticky status

If the compositor honors this request, the zcosmic_toplevel_handle_v1.state event will be sent.

pub fn move_to_ext_workspace( &self, toplevel: &ZcosmicToplevelHandleV1, workspace: &ExtWorkspaceHandleV1, output: &WlOutput, )

move toplevel to workspace

Move window to workspace, on given output.